#
# spec file for package pam_radius
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pam_radius
Version:        2.0.0
Release:        2.6
Summary:        A PAM Module for User Authentication using a Radius Server
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            http://freeradius.org/pam_radius_auth/
Source0:        https://github.com/FreeRADIUS/pam_radius/archive/release_2_0_0.tar.gz#/%{name}-release_2_0_0.tar.gz
Source1:        baselibs.conf
BuildRequires:  pam-devel
Requires:       pam

%description
This is the PAM to RADIUS authentication module. It allows any PAM-capable
machine to become a RADIUS client for authentication and accounting
requests. You will need a RADIUS server to perform the actual
authentication.

%prep
%setup -q -n %{name}-release_2_0_0

%build
export CFLAGS="%{optflags} -fPIC"
%configure
%make_build

%install
install -d -m 755 %{buildroot}%{_pam_moduledir}
install -m 755 pam_radius_auth.so %{buildroot}%{_pam_moduledir}
install -d -m 750 %{buildroot}%{_sysconfdir}/raddb/
install -m 600 pam_radius_auth.conf %{buildroot}%{_sysconfdir}/raddb/server

%files
%license LICENSE
%doc Changelog README.rst TODO USAGE index.html pam_radius_auth.conf
%attr(750,root,radiusd) %dir %{_sysconfdir}/raddb/
%config(noreplace) %{_sysconfdir}/raddb/server
%{_pam_moduledir}/pam_radius_auth.so

%changelog
* Mon Jul 24 2023 Ludwig Nussel <lnussel@suse.com>
- Use %%_pam_moduledir (boo#1190958)
* Tue Apr 27 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.0.0
  * Add IPv6 support
  * environment variable attribute Framed-IP-Address when present
  * add Management-Privilege-Level attribute support
  * Honor radius prompt attribute during challenge response
  * Add support for Linux VRF (SO_BINDTODEVICE), use per-server
    sockets if src_ip or vrf are requested
  * Use per-server socket if src_ip is set in config file
  * Fix memory leak in add_nas_ip_address
  * Add Calling-Station-Id to accounting requests.
  * Thread safety fixes
  * many other fixes including a fix for boo#1163933 known as
    CVE-2015-9542
* Mon Apr  6 2015 aj@ajaissle.de
- Some spec cleanups
* Sun Mar  8 2015 p.drouand@gmail.com
- Update to version 1.4.0
  * The entry of the ChangeLog for this version is empty
- Use %%configure macro
- Enable parallel build with %%{?_smp_mflags}
- Remove obsolete patches
  * pam_radius-1.3.16.diff
  * pam_radius-md5-ppc-fix.patch
- Use download Url as source
- Remove obsolete AUTHORS section
- Do not copy INSTALL file into the package
* Fri May 31 2013 varkoly@suse.com
- Fix /etc/raddb attributes to avoid conflict with freeradius-server
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb 27 2008 jdelvare@suse.de
- Fix MD5 support on PPC (360648).
* Wed May 17 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Fix linking of shared library.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Nov 28 2003 stark@suse.de
- update to 1.3.16
  * Added dummy pam_sm_acct_mgmt() function, which is
    needed by pppd 2.4
  * Increase the allowed length of user names
* Mon Aug 18 2003 stark@suse.de
- packaged /etc/raddb with mode 755 (#29062)
* Wed Jun 12 2002 stark@suse.de
- update to version 1.3.15
  * Bug fix: don't try to free() static storage when using
    skip_passwd
  * Implement retry option
- use %%{_lib} for 32/64bit coexistence
* Tue Sep 18 2001 stark@suse.de
- update to version 1.3.14:
  - Solaris 8 changed their header files for PAM.                                 - Bug fix to work on HURD: Don't use PATH_MAX.
* Wed May 23 2001 stark@suse.de
- update to version 1.3.13
* Tue Mar 13 2001 stark@suse.de
- update to version 1.3.12 (security fixes)
* Thu Jan  4 2001 stark@suse.de
- initial package
